<!DOCTYPE html>
<html lang='{% block html-lang %}en-gb{% endblock %}' {% block html-attributes %}{% endblock %}>
  <head {% block head-attributes %}{% endblock %}>
    {% block head-charset %}
      <meta charset='UTF-8'>
    {% endblock %}
    {% block head-block %}{% endblock %}
    <script>
      window.CAPE = {};
      window.CAPE.stage = function(stage) {
        document.documentElement.className = 'js-' + stage;
      }
      CAPE.timeout = setTimeout( CAPE.stage('timeout'), 5000 );
      CAPE.stage('capable');
    </script>
    {% block javascript-head %}{% endblock %}
  </head>
  <body {% block body-attributes %}{% endblock %} class='{% block body-class %}{% endblock %}'>
    
    {% block body-sheath %}{% endblock %}
    
    {% block javascript-variables %}{% endblock %}
    {% block javascript-libraries %}{% endblock %}
    {% block javascript-enhance %}{% endblock %}
    <script>
      clearTimeout(CAPE.timeout);
      CAPE.stage('ready');
    </script>
    {% block javascript-asynchronous %}{% endblock %}
    {% block javascript-analytics %}{% endblock %}
  </body>
</html>
